@@ -71,7 +71,8 @@ class Geo_common:
         # groups: 每个比对组包含的样本 , dict = {group1 : [sample1 , smaple2] , group2 : [sample3 , sample4]}
         self.groups = collections.defaultdict(list)
         for sample in self.samples:
-            self.groups[self.samples[sample]["group"]].append(sample)
+            for group in self.samples[sample]["group"]:
+                self.groups[group].append(sample)
         # compare_group: 比对组信息 , list = [treat__control]
         self.compare_group = []
         for line in ParserXLS.fetch_row(excel, main_name, "COMPARE_GROUP")[1:]:
